@@ -168,9 +168,13 @@ func TestLoadbalancersCRUD(t *testing.T) {
 
 	listenerName := ""
 	listenerDescription := ""
+	listenerHeaders := map[string]string{
+		"X-Forwarded-For": "true",
+	}
 	updateListenerOpts := listeners.UpdateOpts{
-		Name:        &listenerName,
-		Description: &listenerDescription,
+		Name:          &listenerName,
+		Description:   &listenerDescription,
+		InsertHeaders: &listenerHeaders,
 	}
 	_, err = listeners.Update(lbClient, listener.ID, updateListenerOpts).Extract()
 	th.AssertNoErr(t, err)
@@ -186,6 +190,7 @@ func TestLoadbalancersCRUD(t *testing.T) {
 
 	th.AssertEquals(t, newListener.Name, listenerName)
 	th.AssertEquals(t, newListener.Description, listenerDescription)
+	th.AssertDeepEquals(t, newListener.InsertHeaders, listenerHeaders)
 
 	listenerStats, err := listeners.GetStats(lbClient, listener.ID).Extract()
 	th.AssertNoErr(t, err)
@@ -298,9 +303,11 @@ func TestLoadbalancersCRUD(t *testing.T) {
 	defer DeleteL7Policy(t, lbClient, lb.ID, policy.ID)
 	defer DeleteL7Rule(t, lbClient, lb.ID, policy.ID, rule.ID)
 
-	// Update listener's default pool ID
+	// Update listener's default pool ID and remove headers
+	listenerHeaders = map[string]string{}
 	updateListenerOpts = listeners.UpdateOpts{
 		DefaultPoolID: &pool.ID,
+		InsertHeaders: &listenerHeaders,
 	}
 	_, err = listeners.Update(lbClient, listener.ID, updateListenerOpts).Extract()
 	th.AssertNoErr(t, err)
@@ -315,6 +322,7 @@ func TestLoadbalancersCRUD(t *testing.T) {
 	tools.PrintResource(t, newListener)
 
 	th.AssertEquals(t, newListener.DefaultPoolID, pool.ID)
+	th.AssertDeepEquals(t, newListener.InsertHeaders, listenerHeaders)
 
 	// Remove listener's default pool ID
 	emptyPoolID := ""
@@ -366,7 +374,7 @@ func TestLoadbalancersCRUD(t *testing.T) {
 		Weight:       &newWeight,
 	}
 	batchMembers := []pools.BatchUpdateMemberOpts{memberOpts}
-	if err := pools.BatchUpdateMembers(lbClient, pool.ID, batchMembers).ExtractErr(); err != nil {
+	if err = pools.BatchUpdateMembers(lbClient, pool.ID, batchMembers).ExtractErr(); err != nil {
 		t.Fatalf("Unable to batch update members")
 	}
 
@@ -379,6 +387,20 @@ func TestLoadbalancersCRUD(t *testing.T) {
 
 	tools.PrintResource(t, newMember)
 
+	// delete members from the pool
+	if err = pools.BatchUpdateMembers(lbClient, pool.ID, []pools.BatchUpdateMemberOpts{}).ExtractErr(); err != nil {
+		t.Fatalf("Unable to delete members")
+	}
+
+	if err = WaitForLoadBalancerState(lbClient, lb.ID, "ACTIVE", loadbalancerActiveTimeoutSeconds); err != nil {
+		t.Fatalf("Timed out waiting for loadbalancer to become active")
+	}
+
+	pool, err = pools.Get(lbClient, pool.ID).Extract()
+	th.AssertNoErr(t, err)
+
+	tools.PrintResource(t, pool)
+
 	// Monitor
 	monitor, err := CreateMonitor(t, lbClient, lb, newPool)
 	th.AssertNoErr(t, err)
@@ -386,9 +408,11 @@ func TestLoadbalancersCRUD(t *testing.T) {
 
 	monName := ""
 	newDelay := tools.RandomInt(20, 30)
+	newMaxRetriesDown := tools.RandomInt(4, 10)
 	updateMonitorOpts := monitors.UpdateOpts{
-		Name:  &monName,
-		Delay: newDelay,
+		Name:           &monName,
+		Delay:          newDelay,
+		MaxRetriesDown: newMaxRetriesDown,
 	}
 	_, err = monitors.Update(lbClient, monitor.ID, updateMonitorOpts).Extract()
 	th.AssertNoErr(t, err)
@@ -404,6 +428,7 @@ func TestLoadbalancersCRUD(t *testing.T) {
 
 	th.AssertEquals(t, newMonitor.Name, monName)
 	th.AssertEquals(t, newMonitor.Delay, newDelay)
+	th.AssertEquals(t, newMonitor.MaxRetriesDown, newMaxRetriesDown)
 }
 
 func TestLoadbalancersCascadeCRUD(t *testing.T) {
@@ -506,8 +531,10 @@ func TestLoadbalancersCascadeCRUD(t *testing.T) {
 	th.AssertNoErr(t, err)
 
 	newDelay := tools.RandomInt(20, 30)
+	newMaxRetriesDown := tools.RandomInt(4, 10)
 	updateMonitorOpts := monitors.UpdateOpts{
-		Delay: newDelay,
+		Delay:          newDelay,
+		MaxRetriesDown: newMaxRetriesDown,
 	}
 	_, err = monitors.Update(lbClient, monitor.ID, updateMonitorOpts).Extract()
 	th.AssertNoErr(t, err)
@@ -521,4 +548,6 @@ func TestLoadbalancersCascadeCRUD(t *testing.T) {
 
 	tools.PrintResource(t, newMonitor)
 
+	th.AssertEquals(t, newMonitor.Delay, newDelay)
+	th.AssertEquals(t, newMonitor.MaxRetriesDown, newMaxRetriesDown)
 }
